TensorCircuit is initially a personal project created by @refraction-ray (Shi-Xin Zhang). He began this project in April 2020, inspired by the MPS quantum simulator [mpsim](https://github.com/grmlarose/mpsim) and the introduction of the Google [TensorNetwork](https://github.com/google/TensorNetwork) package. This project is further developed by him during 2020 and the first half of 2021 when he was a Ph.D. candidate at Tsinghua University, with multiple new features and applications added for his research purpose. The original TensorCircuit project is archived now on [GitHub](https://github.com/refraction-ray/tensorcircuit/). He joined Tencent in July 2021 and made this project a more universal open-source framework available on [GitHub](https://github.com/tencent-quantum-lab/tensorcircuit). He is now an Associate Professor at Institue of Physics, Chinese Academy of Sciences and is committed to advancing the framework as tensorcircuit-ng. As the creator and the lead author of TensorCircuit and TensorCircuit-NG, he thanks all the [contributors](https://github.com/tensorcircuit/tensorcircuit-ng#contributors) who have made TensorCircuit and the ecosystem better.
